<?php
add_theme_support( 
    'post-formats', 
    array(
        'aside',
        'gallery',
		//'image',
        'link',
        'quote',
        'video',
        'audio'
    ) 
);
if ( !function_exists( 'junkie_enqueue_admin_scripts' ) ) {
	
    add_action( 'admin_enqueue_scripts', 'junkie_enqueue_admin_scripts' );
	function junkie_enqueue_admin_scripts() {
        wp_register_script( 'junkie-admin', get_template_directory_uri() . '/includes/js/jquery.custom.admin.js', 'jquery' );
        wp_enqueue_script( 'junkie-admin' );
    }
	
}


/**
 * Add a custom Meta Box
 *
 * @param array $meta_box Meta box input data
 */
function junkie_add_meta_box( $meta_box )
{
    if( !is_array($meta_box) ) return false;
    
    // Create a callback function
    $callback = create_function( '$post,$meta_box', 'junkie_create_meta_box( $post, $meta_box["args"] );' );

    add_meta_box( $meta_box['id'], $meta_box['title'], $callback, $meta_box['page'], $meta_box['context'], $meta_box['priority'], $meta_box );
}

/**
 * Create content for a custom Meta Box
 *
 * @param array $meta_box Meta box input data
 */
function junkie_create_meta_box( $post, $meta_box )
{
	// set up for fallback to old way of doing things
	$wp_version = get_bloginfo('version');
	
    if( !is_array($meta_box) ) return false;
    
    if( isset($meta_box['description']) && $meta_box['description'] != '' ){
    	echo '<p>'. $meta_box['description'] .'</p>';
    }
    
	wp_nonce_field( basename(__FILE__), 'junkie_meta_box_nonce' );
	echo '<table class="form-table junkie-metabox-table">';
 
	foreach( $meta_box['fields'] as $field ){
		// Get current post meta data
		$meta = get_post_meta( $post->ID, $field['id'], true );
		echo '<tr><th><label for="'. $field['id'] .'"><strong>'. $field['name'] .'</strong>
			  <span>'. $field['desc'] .'</span></label></th>';
		
		switch( $field['type'] ){	
			case 'text':
				echo '<td><input type="text" name="junkie_meta['. $field['id'] .']" id="'. $field['id'] .'" value="'. ($meta ? $meta : $field['std']) .'" size="30" /></td>';
				break;	
				
			case 'textarea':
				echo '<td><textarea name="junkie_meta['. $field['id'] .']" id="'. $field['id'] .'" rows="8" style=" width:80%">'. ($meta ? $meta : $field['std']) .'</textarea></td>';
				break;
				
			case 'file':
				if( version_compare($wp_version, '3.4.2', '>') ) {
			?> 
				<script>
				jQuery(function($) {
					var frame;

					$('#<?php echo $field['id']; ?>_button').on('click', function(e) {
						e.preventDefault();

						// Set options for 1st frame render
						var options = {
							state: 'insert',
							frame: 'post'
						};

						frame = wp.media(options).open();
						
						// Tweak views
						frame.menu.get('view').unset('gallery');
						frame.menu.get('view').unset('featured-image');
												
						frame.toolbar.get('view').set({
							insert: {
								style: 'primary',
								text: '<?php _e("Insert", "junkie"); ?>',

								click: function() {
									var models = frame.state().get('selection'),
										url = models.first().attributes.url;

									$('#<?php echo $field['id']; ?>').val( url ); 

									frame.close();
								}
							}
						});
						

					});
					
				});
				</script>
			<?php
				} // if version compare
				echo '<td><input type="text" name="junkie_meta['. $field['id'] .']" id="'. $field['id'] .'" value="'. ($meta ? $meta : $field['std']) .'" size="30" class="file" /> <input type="button" class="button" name="'. $field['id'] .'_button" id="'. $field['id'] .'_button" value="Browse" /></td>';
				break;

			case 'images': 
				if( version_compare($wp_version, '3.4.2', '>') ) {
					// Using Wp3.5+
			?>
				<script>
				jQuery(function($) {
					var frame,
					    images = '<?php echo get_post_meta( $post->ID, '_junkie_image_ids', true ); ?>',
					    selection = loadImages(images);

					$('#junkie_images_upload').on('click', function(e) {
						e.preventDefault();

						// Set options for 1st frame render
						var options = {
							title: '<?php _e("Create Featured Gallery", "junkie"); ?>',
							state: 'gallery-edit',
							frame: 'post',
							selection: selection
						};

						// Check if frame or gallery already exist
						if( frame || selection ) {
							options['title'] = '<?php _e("Edit Featured Gallery", "junkie"); ?>';
						}

						frame = wp.media(options).open();
						
						// Tweak views
						frame.menu.get('view').unset('cancel');
						frame.menu.get('view').unset('separateCancel');
						frame.menu.get('view').get('gallery-edit').el.innerHTML = '<?php _e("Edit Featured Gallery", "junkie"); ?>';
						frame.content.get('view').sidebar.unset('gallery'); // Hide Gallery Settings in sidebar

						// When we are editing a gallery
						overrideGalleryInsert();
						frame.on( 'toolbar:render:gallery-edit', function() {
    						overrideGalleryInsert();
						});
						
						frame.on( 'content:render:browse', function( browser ) {
						    if ( !browser ) return;
						    // Hide Gallery Settings in sidebar
						    browser.sidebar.on('ready', function(){
						        browser.sidebar.unset('gallery');
						    });
						    // Hide filter/search as they don't work
						    browser.toolbar.on('ready', function(){
    						    if(browser.toolbar.controller._state == 'gallery-library'){
    						        browser.toolbar.$el.hide();
    						    }
						    });
						});
						
						// All images removed
						frame.state().get('library').on( 'remove', function() {
						    var models = frame.state().get('library');
							if(models.length == 0){
							    selection = false;
    							$.post(ajaxurl, { ids: '', action: 'junkie_save_images', post_id: junkie_ajax.post_id, nonce: junkie_ajax.nonce });
							}
						});
						
						// Override insert button
						function overrideGalleryInsert() {
    						frame.toolbar.get('view').set({
								insert: {
									style: 'primary',
									text: '<?php _e("Save Featured Gallery", "junkie"); ?>',

									click: function() {
										var models = frame.state().get('library'),
										    ids = '';

										models.each( function( attachment ) {
										    ids += attachment.id + ','
										});

										this.el.innerHTML = '<?php _e("Saving...", "junkie"); ?>';
										
										$.ajax({
											type: 'POST',
											url: ajaxurl,
											data: { 
												ids: ids, 
												action: 'junkie_save_images', 
												post_id: junkie_ajax.post_id, 
												nonce: junkie_ajax.nonce 
											},
											success: function(){
    											selection = loadImages(ids);
    											$('#_junkie_image_ids').val( ids );
    											frame.close();
											},
											dataType: 'html'
										}).done( function( data ) {
											$('.junkie-gallery-thumbs').html( data );
										}); 
									}
								}
							});
						}
					});
					
					// Load images
					function loadImages(images) {
						if( images ){
						    var shortcode = new wp.shortcode({
            					tag:    'gallery',
            					attrs:   { ids: images },
            					type:   'single'
            				});
				
						    var attachments = wp.media.gallery.attachments( shortcode );

            				var selection = new wp.media.model.Selection( attachments.models, {
            					props:    attachments.props.toJSON(),
            					multiple: true
            				});
            
            				selection.gallery = attachments.gallery;
            
            				// Fetch the query's attachments, and then break ties from the
            				// query to allow for sorting.
            				selection.more().done( function() {
            					// Break ties with the query.
            					selection.props.set({ query: false });
            					selection.unmirror();
            					selection.props.unset('orderby');
            				});
            				
            				return selection;
						}
						
						return false;
					}
					
				});
				</script>
			<?php
				// SPECIAL CASE:
				// std controls button text; unique meta key for image uploads
				$meta = get_post_meta( $post->ID, '_junkie_image_ids', true );
				$thumbs_output = '';
				$button_text = ($meta) ? __('Edit Gallery', 'junkie') : $field['std'];
				if( $meta ) {
					$field['std'] = __('Edit Gallery', 'junkie');
					$thumbs = explode(',', $meta);
					$thumbs_output = '';
					foreach( $thumbs as $thumb ) {
						$thumbs_output .= '<li>' . wp_get_attachment_image( $thumb, array(32,32) ) . '</li>';
					}
				}

			    echo 
			    	'<td>
			    		<input type="button" class="button" name="' . $field['id'] . '" id="junkie_images_upload" value="' . $button_text .'" />
			    		
			    		<input type="hidden" name="junkie_meta[_junkie_image_ids]" id="_junkie_image_ids" value="' . ($meta ? $meta : 'false') . '" />

			    		<ul class="junkie-gallery-thumbs">' . $thumbs_output . '</ul>
			    	</td>';
			    } else {
			    	// Using pre-WP3.5
			    	echo '<td><input type="button" class="button" name="' . $field['id'] . '" id="junkie_images_upload" value="' . $field['std'] .'" /></td>';
			    }
			    break;
				
			case 'select':
				echo'<td><select name="junkie_meta['. $field['id'] .']" id="'. $field['id'] .'">';
				foreach( $field['options'] as $key => $option ){
					echo '<option value="' . $key . '"';
					if( $meta ){ 
						if( $meta == $key ) echo ' selected="selected"'; 
					} else {
						if( $field['std'] == $key ) echo ' selected="selected"'; 
					}
					echo'>'. $option .'</option>';
				}
				echo'</select></td>';
				break;
				
			case 'radio':
				echo '<td>';
				foreach( $field['options'] as $key => $option ){
					echo '<label class="radio-label"><input type="radio" name="junkie_meta['. $field['id'] .']" value="'. $key .'" class="radio"';
					if( $meta ){ 
						if( $meta == $key ) echo ' checked="checked"'; 
					} else {
						if( $field['std'] == $key ) echo ' checked="checked"';
					}
					echo ' /> '. $option .'</label> ';
				}
				echo '</td>';
				break;
			
			case 'color':
			    if( array_key_exists('val', $field) ) $val = ' value="' . $field['val'] . '"';
			    if( $meta ) $val = ' value="' . $meta . '"';
			    echo '<td>';
                echo '<div class="colorpicker-wrapper">';
                echo '<input type="text" id="'. $field['id'] .'_cp" name="junkie_meta[' . $field['id'] .']"' . $val . ' />';
                echo '<div id="' . $field['id'] . '" class="colorpicker"></div>';
                echo '</div>';
                echo '</td>';
			    break;
				
			case 'checkbox':
			    echo '<td>';
			    $val = '';
                if( $meta ) {
                    if( $meta == 'on' ) $val = ' checked="checked"';
                } else {
                    if( $field['std'] == 'on' ) $val = ' checked="checked"';
                }

                echo '<input type="hidden" name="junkie_meta['. $field['id'] .']" value="off" />
                <input type="checkbox" id="'. $field['id'] .'" name="junkie_meta['. $field['id'] .']" value="on"'. $val .' /> ';
			    echo '</td>';
			    break;
			default:
				echo '<td>';
				echo $field['std'];
				echo '</td>';
		}
		
		echo '</tr>';
	}
 
	echo '</table>';
}

/**
 * Save custom Meta Box
 *
 * @param int $post_id The post ID
 */
function junkie_save_meta_box( $post_id ) {

	if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) 
		return;
	
	if ( !isset($_POST['junkie_meta']) || !isset($_POST['junkie_meta_box_nonce']) || !wp_verify_nonce( $_POST['junkie_meta_box_nonce'], basename( __FILE__ ) ) )
		return;
	
	if ( 'page' == $_POST['post_type'] ) {
		if ( !current_user_can( 'edit_page', $post_id ) ) return;
	} else {
		if ( !current_user_can( 'edit_post', $post_id ) ) return;
	}
 
	foreach( $_POST['junkie_meta'] as $key=>$val ){
		update_post_meta( $post_id, $key, stripslashes(htmlspecialchars($val)) );
	}

}
add_action( 'save_post', 'junkie_save_meta_box' );

/**
 * Save image ids
 */
function junkie_save_images() {

	if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) 
		return;
	
	if ( !isset($_POST['ids']) || !isset($_POST['nonce']) || !wp_verify_nonce( $_POST['nonce'], 'junkie-ajax' ) )
		return;
	
	if ( !current_user_can( 'edit_posts' ) ) return;
 
	$ids = strip_tags(rtrim($_POST['ids'], ','));
	update_post_meta($_POST['post_id'], '_junkie_image_ids', $ids);

	// update thumbs
	$thumbs = explode(',', $ids);
	$thumbs_output = '';
	foreach( $thumbs as $thumb ) {
		$thumbs_output .= '<li>' . wp_get_attachment_image( $thumb, array(32,32) ) . '</li>';
	}

	echo $thumbs_output;

	die();
}
add_action('wp_ajax_junkie_save_images', 'junkie_save_images');


/*-----------------------------------------------------------------------------------*/
/*	Register related Scripts and Styles
/*-----------------------------------------------------------------------------------*/

function junkie_metabox_portfolio_scripts() {
    global $post;
    $wp_version = get_bloginfo('version');
    
	wp_enqueue_script('media-upload');
	if( version_compare( $wp_version, '3.4.2', '<=') ) {
		// Using pre-WP3.5
		wp_enqueue_script('thickbox');
		wp_register_script('junkie-upload', get_template_directory_uri().'/includes/js/upload-button.js', array('jquery','media-upload','thickbox'));
		wp_enqueue_script('junkie-upload');

		wp_enqueue_style('thickbox');

	}

	echo "<link rel=\"stylesheet\" href=\"".get_template_directory_uri()."/includes/css/admin_meta.css\" type=\"text/css\"/>";	
	
	if( isset($post) ) {
		wp_localize_script( 'jquery', 'junkie_ajax', array(
		    'post_id' => $post->ID,
		    'nonce' => wp_create_nonce( 'junkie-ajax' )
		) );
	}
}
add_action('admin_enqueue_scripts', 'junkie_metabox_portfolio_scripts');

/**
 * Create the Post meta boxes
 */
    
add_action('add_meta_boxes', 'junkie_metabox_posts');
function junkie_metabox_posts(){
	    
	/* Create a gallery metabox -----------------------------------------------------*/
    $meta_box = array(
		'id' => 'junkie-metabox-post-gallery',
		'title' =>  __('Gallery Settings', 'junkie'),
		'description' => __('Set up your gallery.', 'junkie'),
		'page' => 'post',
		'context' => 'normal',
		'priority' => 'high',
		'fields' => array(
			array(
					'name' =>  __('Upload Images', 'junkie'),
					'desc' => __('Click to upload images.', 'junkie'),
					'id' => '_junkie_gallery_upload',
					'type' => 'images',
                    'std' => __('Upload Images', 'junkie')
				)
		)
	);
    junkie_add_meta_box( $meta_box );

    /* Create a quote metabox -----------------------------------------------------*/
    $meta_box = array(
		'id' => 'junkie-metabox-post-quote',
		'title' =>  __('Quote Settings', 'junkie'),
		'description' => __('Input the quote.', 'junkie'),
		'page' => 'post',
		'context' => 'normal',
		'priority' => 'high',
		'fields' => array(
			array(
					'name' =>  __('Quote', 'junkie'),
					'desc' => __('Input the quote content.', 'junkie'),
					'id' => '_junkie_quote_quote',
					'type' => 'textarea',
                    'std' => ''
				),
			array(
					'name' =>  __('Quote Author', 'junkie'),
					'desc' => __('Input the quote author.', 'junkie'),
					'id' => '_junkie_quote_author',
					'type' => 'text',
                    'std' => ''
				)				
		)
	);
    junkie_add_meta_box( $meta_box );
	
	/* Create a link metabox ----------------------------------------------------*/
	$meta_box = array(
		'id' => 'junkie-metabox-post-link',
		'title' =>  __('Link Settings', 'junkie'),
		'description' => __('Input your link', 'junkie'),
		'page' => 'post',
		'context' => 'normal',
		'priority' => 'high',
		'fields' => array(
			array(
					'name' =>  __('The Link', 'junkie'),
					'desc' => __('Input your link. e.g., http://www.theme-junkie.com', 'junkie'),
					'id' => '_junkie_link_url',
					'type' => 'text',
					'std' => ''
				)
		)
	);
    junkie_add_meta_box( $meta_box );
    
    /* Create a video metabox -------------------------------------------------------*/
    $meta_box = array(
		'id' => 'junkie-metabox-post-video',
		'title' => __('Video Settings', 'junkie'),
		'description' => __('These settings enable you to embed videos into your posts.', 'junkie'),
		'page' => 'post',
		'context' => 'normal',
		'priority' => 'high',
		'fields' => array(
/*			array( 
					'name' => __('Video Height', 'junkie'),
					'desc' => __('The video height (e.g. 150).', 'junkie'),
					'id' => '_junkie_video_height',
					'type' => 'text',
					'std' => '150'
				),
			array( 
					'name' => __('M4V File URL', 'junkie'),
					'desc' => __('The URL to the .m4v video file', 'junkie'),
					'id' => '_junkie_video_m4v',
					'type' => 'text',
					'std' => ''
				),
			array( 
					'name' => __('OGV File URL', 'junkie'),
					'desc' => __('The URL to the .ogv video file', 'junkie'),
					'id' => '_junkie_video_ogv',
					'type' => 'text',
					'std' => ''
				),*/
			array( 
					'name' => __('Video File', 'junkie'),
					'desc' => __('The URL to video file support format "<strong>mp4,webm,ogv,flv</strong>".', 'junkie'),
					'id' => '_junkie_video_file_url',
					'type' => 'file',
					'std' => ''
				),				
			array( 
					'name' => __('Poster Image', 'junkie'),
					'desc' => __('The preview image.', 'junkie'),
					'id' => '_junkie_video_poster_url',
					'type' => 'file',
					'std' => ''
				),
			array(
					'name' => __('Embedded Code', 'junkie'),
					'desc' => __('If you are using something other than self hosted video such as Youtube or Vimeo, paste the embed code here. <br><br> This field will override the above.', 'junkie'),
					'id' => '_junkie_video_embed_code',
					'type' => 'textarea',
					'std' => ''
				)
		)
	);
	junkie_add_meta_box( $meta_box );
	
	/* Create an audio metabox ------------------------------------------------------*/
	$meta_box = array(
		'id' => 'junkie-metabox-post-audio',
		'title' =>  __('Audio Settings', 'junkie'),
		'description' => __('These settings enable you to embed audio into your posts.', 'junkie'),
		'page' => 'post',
		'context' => 'normal',
		'priority' => 'high',
		'fields' => array(
/*			array( 
					'name' => __('MP3 File URL', 'junkie'),
					'desc' => __('The URL to the .mp3 audio file', 'junkie'),
					'id' => '_junkie_audio_mp3',
					'type' => 'text',
					'std' => ''
				),
			array( 
					'name' => __('OGA File URL', 'junkie'),
					'desc' => __('The URL to the .oga, .ogg audio file', 'junkie'),
					'id' => '_junkie_audio_ogg',
					'type' => 'text',
					'std' => ''
				),*/
			array( 
					'name' => __('Audio File', 'junkie'),
					'desc' => __('The URL to audio file support format "<strong>mp3,m4a</strong>".', 'junkie'),
					'id' => '_junkie_audio_file_url',
					'type' => 'file',
					'std' => ''
				),				
				array( 
					'name' => __('Audio Poster Image', 'junkie'),
					'desc' => __('The preview image for this audio track', 'junkie'),
					'id' => '_junkie_audio_poster_url',
					'type' => 'file',
					'std' => ''
				),
				array(
						'name' => __('Embedded Code', 'junkie'),
						'desc' => __('If you are using something other than self hosted audio such as Youtube or Vimeo, paste the embed code here. <br><br> This field will override the above.', 'junkie'),
						'id' => '_junkie_audio_embed_code',
						'type' => 'textarea',
						'std' => ''
					)				
				/*,
			array( 
					'name' => __('Audio Poster Image Height', 'junkie'),
					'desc' => __('The height of the poster image', 'junkie'),
					'id' => '_junkie_audio_height',
					'type' => 'text',
					'std' => ''
				)*/
		)
	);
	junkie_add_meta_box( $meta_box );
}
